define(
//begin v1.x content
({
	smiley: "Infoga känslolägesikon",
	emoticonSmile: "ler",
	emoticonLaughing: "skrattar",
	emoticonWink: "blinkar med ena ögat",
	emoticonGrin: "ler stort",
	emoticonCool: "cool",
	emoticonAngry: "arg",
	emoticonHalf: "halvt leende",
	emoticonEyebrow: "lyfter på ena ögonbrynet",
	emoticonFrown: "rynkar pannan",
	emoticonShy: "blyg",
	emoticonGoofy: "knasig",
	emoticonOops: "hoppsan",
	emoticonTongue: "räcker ut tungan",
	emoticonIdea: "idé",
	emoticonYes: "ja",
	emoticonNo: "nej",
	emoticonAngel: "ängel",
	emoticonCrying: "gråter",
	emoticonHappy: "glad"
})

//end v1.x content
);
